@@ -31,7 +31,8 @@ GdaConnection     *components_connection_open (const gchar *name,
 					       const gchar *password,
 					       gboolean only_if_exists,
 					       gboolean dont_ref);
-GdaConnection     *components_connection_open_dialog (gchar **selected_name);
+GdaConnection     *components_connection_open_dialog (GtkWidget *parent,
+						      gchar **selected_name);
 void               components_connection_close (GdaConnection *cnc);
 
 G_END_DECLS
